summaryrefslogtreecommitdiffstats
path: root/kicker/extensions/dockbar
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:26:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:26:07 -0600
commit43d99cc2477266cb9072e179137f0e8485370b3d (patch)
tree0d4d47e5497a1a1465edf8263f57b72725577239 /kicker/extensions/dockbar
parent6354e6b3babad3ed0f5e314735bbbc01d1988eb2 (diff)
downloadtdebase-43d99cc2477266cb9072e179137f0e8485370b3d.tar.gz
tdebase-43d99cc2477266cb9072e179137f0e8485370b3d.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'kicker/extensions/dockbar')
-rw-r--r--kicker/extensions/dockbar/dockbarextension.cpp12
-rw-r--r--kicker/extensions/dockbar/dockbarextension.h2
-rw-r--r--kicker/extensions/dockbar/dockcontainer.cpp2
3 files changed, 8 insertions, 8 deletions
diff --git a/kicker/extensions/dockbar/dockbarextension.h b/kicker/extensions/dockbar/dockbarextension.h
index eada2583b..4a5dff41f 100644
--- a/kicker/extensions/dockbar/dockbarextension.h
+++ b/kicker/extensions/dockbar/dockbarextension.h
@@ -61,7 +61,7 @@ protected:
void mouseReleaseEvent(TQMouseEvent *);
void mouseMoveEvent(TQMouseEvent *);
private:
- KWinModule* kwin_module;
+ KWinModule* twin_module;
DockContainer::Vector containers;
// handle the dragging of applets
diff --git a/kicker/extensions/dockbar/dockcontainer.cpp b/kicker/extensions/dockbar/dockcontainer.cpp
index 1d281619a..f6ac6bd33 100644
--- a/kicker/extensions/dockbar/dockcontainer.cpp
+++ b/kicker/extensions/dockbar/dockcontainer.cpp
@@ -23,7 +23,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqwidget.h>
#include <tqtooltip.h>
-#include <kwin.h>
+#include <twin.h>
#include <tqvalidator.h>
#include <kinputdialog.h>
#include <klocale.h>
diff --git a/kicker/extensions/dockbar/dockbarextension.cpp b/kicker/extensions/dockbar/dockbarextension.cpp
index aee6a728c..da20a2a61 100644
--- a/kicker/extensions/dockbar/dockbarextension.cpp
+++ b/kicker/extensions/dockbar/dockbarextension.cpp
@@ -23,12 +23,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#undef Bool // For enable-final
#include <klocale.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kdebug.h>
#include <kconfig.h>
#include <kprocess.h>
#include <kshell.h>
-#include <kwin.h>
+#include <twin.h>
#include <kstandarddirs.h>
#include <kmessagebox.h>
#include <kapplication.h>
@@ -57,8 +57,8 @@ DockBarExtension::DockBarExtension(const TQString& configFile, Type type,
: KPanelExtension(configFile, type, actions, parent, name)
{
dragging_container = 0;
- kwin_module = new KWinModule(TQT_TQOBJECT(this));
- connect( kwin_module, TQT_SIGNAL( windowAdded(WId) ), TQT_SLOT( windowAdded(WId) ) );
+ twin_module = new KWinModule(TQT_TQOBJECT(this));
+ connect( twin_module, TQT_SIGNAL( windowAdded(WId) ), TQT_SLOT( windowAdded(WId) ) );
setMinimumSize(DockContainer::sz(), DockContainer::sz());
tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
loadContainerConfig();
@@ -154,8 +154,8 @@ void DockBarExtension::windowAdded(WId win)
kdDebug() << "Could not read XClassHint of window " << win << endl;
return;
}
- /* withdrawing the window prevents kwin from managing the window,
- which causes the double-launch bug (one instance from the kwin
+ /* withdrawing the window prevents twin from managing the window,
+ which causes the double-launch bug (one instance from the twin
session, and one from the dockbar) bug when kde is restarted */
if (resIconwin != win) {
XWithdrawWindow( qt_xdisplay(), win, qt_xscreen() );